lcvtoolbox.integrations.cvat.api.api\_requests.CvatApiJobAnnotations
====================================================================

.. currentmodule:: lcvtoolbox.integrations.cvat.api.api_requests

.. autoclass:: CvatApiJobAnnotations
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CvatApiJobAnnotations.__init__
      ~CvatApiJobAnnotations.construct
      ~CvatApiJobAnnotations.copy
      ~CvatApiJobAnnotations.dict
      ~CvatApiJobAnnotations.from_orm
      ~CvatApiJobAnnotations.json
      ~CvatApiJobAnnotations.model_construct
      ~CvatApiJobAnnotations.model_copy
      ~CvatApiJobAnnotations.model_dump
      ~CvatApiJobAnnotations.model_dump_json
      ~CvatApiJobAnnotations.model_json_schema
      ~CvatApiJobAnnotations.model_parametrized_name
      ~CvatApiJobAnnotations.model_post_init
      ~CvatApiJobAnnotations.model_rebuild
      ~CvatApiJobAnnotations.model_validate
      ~CvatApiJobAnnotations.model_validate_json
      ~CvatApiJobAnnotations.model_validate_strings
      ~CvatApiJobAnnotations.parse_file
      ~CvatApiJobAnnotations.parse_obj
      ~CvatApiJobAnnotations.parse_raw
      ~CvatApiJobAnnotations.schema
      ~CvatApiJobAnnotations.schema_json
      ~CvatApiJobAnnotations.update_forward_refs
      ~CvatApiJobAnnotations.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CvatApiJobAnnotations.model_computed_fields
      ~CvatApiJobAnnotations.model_config
      ~CvatApiJobAnnotations.model_extra
      ~CvatApiJobAnnotations.model_fields
      ~CvatApiJobAnnotations.model_fields_set
      ~CvatApiJobAnnotations.version
      ~CvatApiJobAnnotations.tags
      ~CvatApiJobAnnotations.shapes
      ~CvatApiJobAnnotations.tracks
   
   